PullToRefresh

Struct PullToRefresh 

pub struct PullToRefresh { /* private fields */ }
A widget that allows the user to pull to refresh.

Implementations

Source

impl PullToRefresh

pub fn new(loading: bool) -> Self

Creates a new pull to refresh widget. If loading is true, the widget will show the loading indicator.

pub fn min_refresh_distance(self, min_refresh_distance: f32) -> Self

Sets the minimum distance the user needs to drag to trigger a refresh.

pub fn id(self, id: Id) -> Self

You need to provide a id if you use multiple pull to refresh widgets at once.

pub fn can_refresh(self, can_refresh: bool) -> Self

If can_refresh is false, pulling will not trigger a refresh.

pub fn ui<T>( self, ui: &mut Ui, content: impl FnOnce(&mut Ui) -> T, ) -> PullToRefreshResponse<T>

Shows the pull to refresh widget. Note: If you want to use the pull to refresh widget in a scroll area, use Self::scroll_area_ui. You might want to disable text selection via egui::style::Interaction to avoid conflicts with the drag gesture.

pub fn scroll_area_ui<T>( self, ui: &mut Ui, content: impl FnOnce(&mut Ui) -> ScrollAreaOutput<T>, ) -> PullToRefreshResponse<ScrollAreaOutput<T>>

Shows the pull to refresh widget, wrapping a egui::ScrollArea. Pass the output of the scroll area to the content function.